package CSS::Croco::Term::URI;

use utf8;
use strict;
use warnings;
use base 'CSS::Croco::Term';

1;
__END__

=head1 NAME

CSS::Croco::Term::URI - URI value

=head1 DESCRIPTION

Handles URLs like url(http://google.com)

=head1 METHODS

=head2 get

Returns new URI object.


=head1 BUGS

=head1 NOTES

=head1 AUTHOR

Andrey Kostenko (), <andrey@kostenko.name>

=head1 COMPANY

Rambler Internet Holding

=head1 CREATED

03.11.2009 02:43:44 MSK

=cut

use strict;
use warnings;



